# Rest

[![Gem Version](https://badge.fury.io/rb/sinatra-rest-base.svg)](http://badge.fury.io/rb/sinatra-rest-base)

[![sinatra-rest-base API Documentation](https://www.omniref.com/ruby/gems/sinatra-rest-base.png)](https://www.omniref.com/ruby/gems/sinatra-rest-base)

Core base for quick configuration of Sinatra for RESTful Services

#### What Does the Core Cover

* Adherence to [API Standards] (https://github.com/RESTful-Forest/Sinatra-Rest-Base/wiki/RESTful-API-Standards)
* Basic Configuration
  * Storing the IO String Request Body into a global hash 'request_body'
  * Processing the response body into the proper accepted mime type (application/json, text/xml, ect.) depending on the HTTP_ACCEPT header.
      * Defaults to application/json
  * Processing the version of the application being accessed via HTTP_ACCEPT header
* Basic Error Handeling
  * Handles Authentication Errors, StandardError, Error status codes 400..510
  * Implements Basic Error Classes
    * InvalidRequest
    * More to come soon!
* Simple authentication setup
  * Provides a base authentication class to inherit from and create a quick authentication process.
  * Provides an easy authentication setup through the configuration setup of Sinatra.

## Installation

Add this line to your application's Gemfile:

    gem 'sinatra-rest-base'

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install sinatra-rest-base

## Usage

#### Setting Up the Application 

Normal Sinatra Appication inherit from either Sinatra::Application or Sinatra::Base. With sinatra-rest-base you just need to inherit from Rest::Application.

In your main application file, do the following:

```
require 'rest_base'

class SinatraApp < RestBase::Application
end
```

then in any other partial class file of the main application file, you just have to name the class like follow:

```
require 'rest_base'

class SinatraApp

  get '/' do
    {
      :result => "This is so easy now!"
    }
  end

end
```

Bam, that easy!

## [Documentation Wiki] (https://github.com/RESTful-Forest/Sinatra-Rest-Base/wiki/Documentation)

## Contributing

1. Fork it ( https://github.com/[my-github-username]/sintara-rest-base/fork )
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new Pull Request
